using System;
using System.Collections;
using System.Data;
using System.Data.SqlClient;
using System.Diagnostics;
using DataAccessLayer;
using Microsoft.Practices.EnterpriseLibrary.Data;
/// <summary>
/// Summary description for Licensing
/// </summary>
public class Licensing
{
    DataAccess objDataAccess = new DataAccess();
    Hashtable htable = new Hashtable();
    Database db = DatabaseFactory.CreateDatabase("DBConnection");
    /// <summary>
    /// Insert license's module and page information into TA_Tbl_Page.
    /// </summary>
    /// <param name="pageId">The page id.</param>
    /// <param name="displayName">The display name.</param>
    /// <param name="path">The path.</param>
    /// <param name="parentId">The parent id.</param>
    /// <param name="orderBy">The order by.</param>
    public void InsertIntoTATblPage(float pageId, string displayName, string path, int parentId, decimal orderBy)
    {
        try
        {
            htable.Clear();
            htable.Add("@pageId", pageId);
            htable.Add("@displayName", displayName);
            htable.Add("@path", path);
            htable.Add("@parentId", parentId);
            htable.Add("@orderBy", orderBy);
            objDataAccess.GetStoredProcCommand(htable, "Proc_TA_InsertTATblPage");
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
    }
    /// <summary>
    /// Inserts license info into protection table.
    /// </summary>
    /// <param name="customerId">The customer id.</param>
    /// <param name="softwareId">The software id.</param>
    /// <param name="packageId">The package id.</param>
    /// <param name="noOfConcurrentUser">The no of concurrent user.</param>
    /// <param name="expiryDate">The expiry date.</param>
    /// <param name="dateOfIssue">The date of issue.</param>
    public void InsertIntoProtectionTable(string customerId, string packageId, string packageVersion, string noOfConcurrentUser, string noOfEmployee, string noOfTerminal, string macAddress, string licenseGenerationDate, string expiryDate, string module, string module1, string module2, string module3, string module4, string module5, string pageStatusFalse)
    {
        try
        {
            htable.Clear();
            htable.Add("@customerId", customerId);
            htable.Add("@packageId", packageId);
            htable.Add("@packageVersion", packageVersion);
            htable.Add("@noOfConcurrentUser", noOfConcurrentUser);
            htable.Add("@noOfEmployee", noOfEmployee);
            htable.Add("@noOfTerminal", noOfTerminal);
            htable.Add("@macAddress", macAddress);
            htable.Add("@licenseGenerationDate", licenseGenerationDate);
            htable.Add("@expiryDate", expiryDate);
            htable.Add("@module", module);
            htable.Add("@module1", module1);
            htable.Add("@module2", module2);
            htable.Add("@module3", module3);
            htable.Add("@module4", module4);
            htable.Add("@module5", module5);
            htable.Add("@pageStatusFalse", pageStatusFalse);
            objDataAccess.GetStoredProcCommand(htable, "Proc_TA_InsertTA_Tbl_LIC_Details");
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
    }
    /// <summary>
    /// Selects from protection table.
    /// </summary>
    /// <returns></returns>
    public DataSet SelectFromProtectionTable()
    {
        DataSet dsLicenseInfo = new DataSet();
        try
        {
            dsLicenseInfo = objDataAccess.ExecuteDataSet("Proc_TA_SelectTA_Tbl_LIC_Details");
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
        return dsLicenseInfo;
    }
    public void InsertIntoTATblPage(DataTable dtModule)
    {
        try
        {
            string strDecryptedString = string.Empty;
            strDecryptedString = Cryptographys.Cryptography.GetDecryptedConnectionString();
            SqlBulkCopy bulkCopy = new SqlBulkCopy(strDecryptedString, SqlBulkCopyOptions.TableLock);
            bulkCopy.DestinationTableName = "TA_Tbl_Page";
            bulkCopy.ColumnMappings.Clear();
            foreach (DataColumn dc in dtModule.Columns)
            {
                bulkCopy.ColumnMappings.Add(new SqlBulkCopyColumnMapping(dc.ColumnName, dc.ColumnName));
            }
            Stopwatch sw = new Stopwatch();
            sw.Start();
            bulkCopy.WriteToServer(dtModule);
            sw.Stop();
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
    }
    public void UpdateDefaultGradeForSE(string gradeName, int gradeLevel, int empAutoId)
    {
        try
        {
            htable.Clear();
            htable.Add("@gradeName", gradeName);
            htable.Add("@gradeLevel", gradeLevel);
            htable.Add("@empAutoId", empAutoId);
            objDataAccess.GetStoredProcCommand(htable, "Proc_TA_UpdateDefaultSE");
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
    }
    public void UpdateDefaultGradeForSEFromDemo(string gradeName, int gradeLevel, int empAutoId)
    {
        try
        {
            htable.Clear();
            htable.Add("@gradeName", gradeName);
            htable.Add("@gradeLevel", gradeLevel);
            htable.Add("@empAutoId", empAutoId);
            objDataAccess.GetStoredProcCommand(htable, "UpdateDefaultGradeForSEFromDemo");
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
    }
    public void UpdateDefaultRights(string enterprisePageIds, string parentIds, int employeeId)
    {
        try
        {
            htable.Clear();
            htable.Add("@enterprisePageIds", enterprisePageIds);
            htable.Add("@parenIds", parentIds);
            htable.Add("@employeeId", employeeId);
            objDataAccess.GetStoredProcCommand(htable, "Proc_TA_UpdateDefaultRights");
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
    }
    /// <summary>
    /// Selects Pending and Forwarded Records Exists
    /// </summary>
    /// <returns></returns>
    public DataSet SelectLICPendingForwardedRecords()
    {
        DataSet dsLicenseInfo = new DataSet();
        try
        {
            dsLicenseInfo = objDataAccess.ExecuteDataSet("Proc_TA_SelectLICPendingForwardedRecords");
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
        return dsLicenseInfo;
    }
    /// <summary>
    /// Added by MAnjula.P on 17-Jan-2014 for updating SE Grade for Entrprises
    /// </summary>
    /// <param name="enterprisePageIds"></param>
    /// <param name="parentIds"></param>
    /// <param name="employeeId"></param>
    public void EnterpriseGradeUpdation()
    {
        try
        {
            objDataAccess.ExecuteNonQuery("Proc_TA_EnterpriseGradeUpdation");
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
    }
    /// <summary>
    /// Added by Manikandan.R on 14-Mar-2014 
    /// To Get the Version Number
    /// </summary>
    /// <param name="enterprisePageIds"></param>
    /// <param name="parentIds"></param>
    /// <param name="employeeId"></param>
    public DataSet GettingVersionNumber()
    {
        DataSet ds = new DataSet();
        try
        {
            ds = objDataAccess.ExecuteDataSet("Proc_TA_GettingVersionNumber");
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
        return ds;
    }
    /// <summary>
    /// Selects from protection table.
    /// </summary>
    /// <returns></returns>
    public DataSet GettingResponseStatus()
    {
        DataSet dsLicenseInfo = new DataSet();
        try
        {
            dsLicenseInfo = objDataAccess.ExecuteDataSet("Proc_TA_GettingResponseStatus");
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
        return dsLicenseInfo;
    }
    /// <summary>
    /// Insert License requested Response details in table
    /// </summary>
    /// <returns></returns>
    public void InsertLicenseResponseData(Int64 ResponseID, string MACAddress, bool Status)
    {
        try
        {
            htable.Clear();
            htable.Add("@RequestID", ResponseID);
            htable.Add("@MacAddress", MACAddress);
            htable.Add("@Status", Status);
            objDataAccess.GetStoredProcCommand(htable, "Proc_TC_InsertResponseDetails");
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
    }
    /// <summary>
    /// 	select Active and top 1 request ID  
    /// </summary>
    /// <returns></returns>
    public DataSet SelectLicenseRequestID()
    {
        DataSet ds = new DataSet();
        try
        {
            ds = objDataAccess.ExecuteDataSet("Proc_OL_SelectLicenseRequestID");
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
        return ds;
    }
    /// <summary>
    /// 	select expiry date from the license expiry table  
    /// </summary>
    /// <returns></returns>
    public DataSet SelectLicenseExpiryDate()
    {
        DataSet ds = new DataSet();
        try
        {
            ds = objDataAccess.ExecuteDataSet("Proc_OL_SelectLicenseExpiryDate");
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
        return ds;
    }
    /// <summary>
    /// 	select top 1 request ID  REACTIVATION License
    /// </summary>
    /// <returns></returns>
    public DataSet SelectLicenseRequestIDReactivation()
    {
        DataSet ds = new DataSet();
        try
        {
            ds = objDataAccess.ExecuteDataSet("Proc_OL_SelectLicenseRequestIDReactivation");
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
        return ds;
    }
    /// <summary>
    /// 	Update of TA_Tbl_LicenseRequestDetail table status after the license get updated
    /// </summary>
    /// <returns></returns>
    public DataSet UpdateResponseDetails(Int64 ResponseID, bool Status)
    {
        DataSet ds = new DataSet();
        try
        {
            htable.Clear();
            htable.Add("@RequestID", ResponseID);
            htable.Add("@Status", Status);
            ds = objDataAccess.GetStoredProcCommand("Proc_TC_UpdateResponseDetails", htable);
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
        return ds;
    }
    public void ActivateEmployeeBasedOnLicence(string strEmpCount)
    {
        try
        {
            htable.Clear();
            htable.Add("@EmployeeCount", strEmpCount);
            objDataAccess.GetStoredProcCommand(htable, "Proc_TA_ActivateEmployeeBasedOnLicence");
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
    }
    public void UpdateUserRightsDetails()
    {
        try
        {            
            objDataAccess.ExecuteNonQuery("Proc_Ta_UpdateLatestVersionDetails_UserRights");
        }
        catch (Exception Ex)
        {
            throw Ex;
        }
    }
}